from setuptools import setup

setup(name='packagesorry',
version='0.0.3',

packages = ['math','ganit'],
package_dir= {
    'math': 'math'
},
description="This code with harry",
long_description='This is very very long description',
author='Harry',


)



"""
from setuptools import setup

setup(name='ganit',
version='0.1.2',
description="This code with harry",
long_description='This is very very long description',
author='Harry',

instaall_require=[])
"""